@@ -5,7 +5,7 @@ import numpy as np
 
 class F1ScoreMetric(tf.keras.metrics.Metric):
     def __init__(self, name="geometric_f1score", n_classes=10, debug=False, f1_method='geometric',
-                 skip_nan=False, tboard_writer=None, **kwargs):
+                 skip_nan=False, tboard_writer=None, sparse=False, **kwargs):
         super(F1ScoreMetric, self).__init__(name=name, **kwargs)
         self.f1_scores = self.add_weight(name="f1score", initializer='zeros', aggregation=tf.VariableAggregation.MEAN)
         self.con_mat = tf.Variable(initial_value=np.zeros((n_classes, n_classes)), dtype=tf.float32,
@@ -15,9 +15,14 @@ class F1ScoreMetric(tf.keras.metrics.Metric):
         self.skip_nan = skip_nan
         self.tboard_writer = tboard_writer
         self.f1_method = f1_method
+        self.sparse = sparse
 
     def update_state(self, y_true, y_pred, sample_weight=None):
-        y_true = tf.cast(tf.reshape(y_true, [-1]), dtype=tf.int32)
+        if self.sparse:
+            y_true = tf.math.argmax(y_true, axis=-1)
+        else:
+            y_true = tf.cast(tf.reshape(y_true, [-1]), dtype=tf.int32)
+
         y_pred = tf.cast(tf.math.argmax(y_pred, axis=-1), dtype=y_true.dtype)
 
         con_mat = tf.cast(tf.math.confusion_matrix(labels=y_true,
